/* Copyright 2019 British Broadcasting Corporation

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License. */

body {
  font-family: sans-serif;
  background: #eee;
  margin: 0;
  color: #555;
}

h2 {
  margin: 0px;
  margin-bottom: 10px;
  font-size: x-large;
  color: #555;
}

button {
  padding: 10px 20px;
  background-color: #ccc;
  border: none;
  font-size: 1em;
}

button:hover {
  background-color: #777;
}

label, label > span   {
  display: block;
  margin: 15px auto;
}

input, textarea, select {
  background-color: transparent; /* Remove background fill */
	border-radius: 0; /* Remove corner curve */
	border: 2px solid #ccc; /* 2px white border */
  height: 45px;
  width: 40%;
  font-size: 1em;
}

textarea {
  font-family: sans-serif;
}

/*------------------- NAV BAR -------------------*/

.navbar {
  top: 0;
  left: 0;
  right: 0;
  width: 100%;
  height: 50px;
  background-color: #777;
  color: white;
  padding: 10px;
  position: -webkit-sticky;
  position: sticky;
}

.navbar > h1 {
  margin-top: 0px;
  color: white;
  display: inline-block;
}

.navbar h1 a {
  font-size: x-large;
  padding: 24px;
}


.navbar a {
  color: white;
  margin-left: 40px;
  text-decoration: none;
  font-size: large;
  padding: 25px;
}

.navbar a:hover {
  background-color: #555;
}

/*------------------- PAGE --------------------*/

.page {
  margin: 2em auto;
  width: 60%;
  border: 10px solid #ccc;
  padding: 15px;
  background: #f1f1f1;
}

.page a {
  color: #555;
  text-decoration: none;
  text-align: center;
}

.page a:hover {
  color: #ccc;
}

/*------------- COLLAPSIBLE -------------*/

.collapsible {
  background-color: #777;
  color: white;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.collapsible a {
  color: white;
}

.active, .collapsible:hover {
  background-color: #555;
}

.content {
  padding: 0 18px;
  max-height: 0;
  overflow: hidden;
  transition: max-height 0.5s ease-out;
  background-color: #f1f1f1;
}
