<!-- Copyright 2019 British Broadcasting Corporation

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License. -->

{% extends "layout.html" %}
{% block body %}

<h2>Register Client</h2>

<form action="{{ url_for('_create_client_post') }}" method="post">
  <label>
    <span>Client Name:</span>
    <input type="text" name="client_name" value="R&amp;D Web Router">
  </label>
  <label>
    <span>Client URI:</span>
    <input type="url" name="client_uri"
            value="http://ipstudio-master.rd.bbc.co.uk/ips-web/#/web-router">
  </label>
  <label>
    <span>Allowed Scope:</span>
    <input type="text" name="scope" value="is04 is05"
            placeholder="space delimited list of scopes">
  </label>
  <label>
    <span>Redirect URIs:</span>
    <textarea name="redirect_uri" cols="30" rows="10" >http://ipstudio-master.rd.bbc.co.uk/ips-web/</textarea>
  </label>
  <label>
    <span>Allowed Grant Types:</span>
    <textarea name="grant_type" cols="30" rows="10" placeholder="grant name">password
authorization_code</textarea>
  </label>
  <label>
    <span>Allowed Response Types:</span>
    <textarea name="response_type" cols="30" rows="10">code</textarea>
  </label>
  <label>
    <span>Token Endpoint Auth Method:</span>
    <select name="token_endpoint_auth_method">
      <option value="client_secret_basic">client_secret_basic</option>
      <option value="client_secret_post">client_secret_post</option>
      <option value="none">none</option>
    </select>
  </label>
  <button>Submit</button>
</form>
{% endblock %}
